"""Generated ATen operator registrations for SkyTorch backend.

This file is auto-generated by hack/gen-aten-ops.py.
Do not edit manually.
"""

from typing import Any, Callable

import torch

from .dispatch import _sky_kernel_fallback


def _sky_kernel_fallback_wrapper(
    op: torch._ops.OpOverload | torch._ops.OpOverloadPacket,
) -> Callable[..., Any]:
    """Create a wrapper that calls _sky_kernel_fallback with the specified op."""

    def wrapper(*args: Any, **kwargs: Any) -> Any:
        return _sky_kernel_fallback(op, *args, **kwargs)

    return wrapper


# Register operators with sky backend
_sky_lib_aten = torch.library.Library("aten", "IMPL")

_sky_lib_aten.impl(
    "_adaptive_avg_pool2d",
    _sky_kernel_fallback_wrapper(torch.ops.aten._adaptive_avg_pool2d.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_adaptive_avg_pool2d.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._adaptive_avg_pool2d.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_adaptive_avg_pool2d_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten._adaptive_avg_pool2d_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_adaptive_avg_pool2d_backward.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._adaptive_avg_pool2d_backward.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_log_softmax",
    _sky_kernel_fallback_wrapper(torch.ops.aten._log_softmax.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_log_softmax.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._log_softmax.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_log_softmax_backward_data",
    _sky_kernel_fallback_wrapper(torch.ops.aten._log_softmax_backward_data.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_log_softmax_backward_data.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._log_softmax_backward_data.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit.no_stats",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit.no_stats),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit.no_stats_out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit.no_stats_out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit_no_training",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit_no_training.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_native_batch_norm_legit_no_training.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._native_batch_norm_legit_no_training.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_softmax",
    _sky_kernel_fallback_wrapper(torch.ops.aten._softmax.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_softmax.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._softmax.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_softmax_backward_data",
    _sky_kernel_fallback_wrapper(torch.ops.aten._softmax_backward_data.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "_softmax_backward_data.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten._softmax_backward_data.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "abs",
    _sky_kernel_fallback_wrapper(torch.ops.aten.abs.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "abs.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.abs.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "abs_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.abs_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "add.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.add.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "add.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.add.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "add.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.add.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "add_.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.add_.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "add_.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.add_.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "addmm",
    _sky_kernel_fallback_wrapper(torch.ops.aten.addmm.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "addmm.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.addmm.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "addmm_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.addmm_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "argmax",
    _sky_kernel_fallback_wrapper(torch.ops.aten.argmax.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "argmax.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.argmax.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "avg_pool2d",
    _sky_kernel_fallback_wrapper(torch.ops.aten.avg_pool2d.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "avg_pool2d.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.avg_pool2d.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "avg_pool2d_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.avg_pool2d_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "avg_pool2d_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.avg_pool2d_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "bmm",
    _sky_kernel_fallback_wrapper(torch.ops.aten.bmm.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "bmm.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.bmm.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "cat",
    _sky_kernel_fallback_wrapper(torch.ops.aten.cat.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "cat.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.cat.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "clone",
    _sky_kernel_fallback_wrapper(torch.ops.aten.clone.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "contiguous",
    _sky_kernel_fallback_wrapper(torch.ops.aten.contiguous.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "convolution",
    _sky_kernel_fallback_wrapper(torch.ops.aten.convolution.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "convolution.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.convolution.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "convolution_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.convolution_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "convolution_backward.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.convolution_backward.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div.Scalar_mode",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div.Scalar_mode),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div.Tensor_mode",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div.Tensor_mode),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div_.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div_.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "div_.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.div_.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "embedding",
    _sky_kernel_fallback_wrapper(torch.ops.aten.embedding.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "embedding_dense_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.embedding_dense_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "eq.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.eq.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "eq.Scalar_out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.eq.Scalar_out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "eq.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.eq.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "eq.Tensor_out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.eq.Tensor_out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "exp",
    _sky_kernel_fallback_wrapper(torch.ops.aten.exp.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "exp.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.exp.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "exp_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.exp_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "expand",
    _sky_kernel_fallback_wrapper(torch.ops.aten.expand.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "fill_.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.fill_.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "fill_.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.fill_.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "flatten.using_ints",
    _sky_kernel_fallback_wrapper(torch.ops.aten.flatten.using_ints),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "full",
    _sky_kernel_fallback_wrapper(torch.ops.aten.full.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "full.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.full.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ge.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ge.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ge.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ge.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gelu",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gelu.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gelu.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gelu.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gelu_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gelu_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gelu_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gelu_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gelu_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gelu_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gt.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gt.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "gt.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.gt.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "index.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.index.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "index.Tensor_out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.index.Tensor_out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "le.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.le.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "le.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.le.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "log",
    _sky_kernel_fallback_wrapper(torch.ops.aten.log.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "log.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.log.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "log_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.log_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "lt.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.lt.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "lt.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.lt.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max.dim",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max.dim),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max.dim_max",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max.dim_max),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max_pool2d_with_indices",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max_pool2d_with_indices.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max_pool2d_with_indices.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max_pool2d_with_indices.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max_pool2d_with_indices_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max_pool2d_with_indices_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "max_pool2d_with_indices_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.max_pool2d_with_indices_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mean",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mean.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mean.dim",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mean.dim),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mean.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mean.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mm",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mm.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mm.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mm.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mul.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mul.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mul.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mul.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mul.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mul.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mul_.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mul_.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "mul_.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.mul_.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "native_batch_norm_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.native_batch_norm_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "native_dropout",
    _sky_kernel_fallback_wrapper(torch.ops.aten.native_dropout.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "native_dropout.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.native_dropout.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "native_dropout_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.native_dropout_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "native_dropout_backward.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.native_dropout_backward.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ne.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ne.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ne.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ne.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "neg",
    _sky_kernel_fallback_wrapper(torch.ops.aten.neg.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "neg.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.neg.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "neg_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.neg_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss2d_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss2d_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss2d_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss2d_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss2d_forward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss2d_forward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss2d_forward.output",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss2d_forward.output),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss_forward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss_forward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "nll_loss_forward.output",
    _sky_kernel_fallback_wrapper(torch.ops.aten.nll_loss_forward.output),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ones",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ones.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "ones.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.ones.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "permute",
    _sky_kernel_fallback_wrapper(torch.ops.aten.permute.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "pow.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.pow.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "pow.Tensor_Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.pow.Tensor_Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "pow.Tensor_Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.pow.Tensor_Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "relu",
    _sky_kernel_fallback_wrapper(torch.ops.aten.relu.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "relu.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.relu.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "relu_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.relu_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "reshape",
    _sky_kernel_fallback_wrapper(torch.ops.aten.reshape.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "rsqrt",
    _sky_kernel_fallback_wrapper(torch.ops.aten.rsqrt.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "rsqrt.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.rsqrt.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "rsqrt_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.rsqrt_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "select.int",
    _sky_kernel_fallback_wrapper(torch.ops.aten.select.int),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sigmoid",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sigmoid.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sigmoid.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sigmoid.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sigmoid_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sigmoid_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sigmoid_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sigmoid_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sigmoid_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sigmoid_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "slice.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.slice.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sqrt",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sqrt.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sqrt.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sqrt.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sqrt_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sqrt_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "squeeze.dim",
    _sky_kernel_fallback_wrapper(torch.ops.aten.squeeze.dim),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "squeeze.dims",
    _sky_kernel_fallback_wrapper(torch.ops.aten.squeeze.dims),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sub.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sub.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sub.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sub.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sub.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sub.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sub_.Scalar",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sub_.Scalar),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sub_.Tensor",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sub_.Tensor),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sum",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sum.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sum.dim_IntList",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sum.dim_IntList),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "sum.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.sum.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "t",
    _sky_kernel_fallback_wrapper(torch.ops.aten.t.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "tanh",
    _sky_kernel_fallback_wrapper(torch.ops.aten.tanh.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "tanh.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.tanh.out),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "tanh_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.tanh_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "tanh_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.tanh_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "tanh_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.tanh_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "threshold_backward",
    _sky_kernel_fallback_wrapper(torch.ops.aten.threshold_backward.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "threshold_backward.grad_input",
    _sky_kernel_fallback_wrapper(torch.ops.aten.threshold_backward.grad_input),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "transpose.int",
    _sky_kernel_fallback_wrapper(torch.ops.aten.transpose.int),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "unsqueeze",
    _sky_kernel_fallback_wrapper(torch.ops.aten.unsqueeze.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "zero_",
    _sky_kernel_fallback_wrapper(torch.ops.aten.zero_.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "zeros",
    _sky_kernel_fallback_wrapper(torch.ops.aten.zeros.default),
    dispatch_key="PrivateUse1",
)

_sky_lib_aten.impl(
    "zeros.out",
    _sky_kernel_fallback_wrapper(torch.ops.aten.zeros.out),
    dispatch_key="PrivateUse1",
)
